@@ -23,7 +23,15 @@ import sys
     show_default=True,
     help="The maximum number of tokens to generate.",
 )
-def solution(text, max_tokens):
+@click.option(
+    "-p",
+    "--prompt",
+    type=str,
+    default=prompt_solution,
+    show_default=True,
+    help="Prompt to use for the completion",
+)
+def solution(text, max_tokens, prompt):
     """
     Process text using OpenAI's GPT-4 model to solve problem.
     """
@@ -34,5 +42,4 @@ def solution(text, max_tokens):
             "OpenAI API key not found. Please set the OPENAI_API_KEY environment variable.", style="bold red")
         sys.exit(1)
 
-    prompt = prompt_solution
     process_text(text, prompt, api_key, max_tokens)
